# Getting Started

Welcome to bfabricPy! This section will help you get up and running quickly.

```{toctree}
:maxdepth: 1
installation
quick_start
configuration
troubleshooting
```

## Next Steps

After getting started, explore our **[User Guides](../user_guides/index)** for practical examples and workflows.

## Quick Links

- [Installation Guide](installation.md)
- [Quick Start Tutorial](quick_start.md)
- [Configuration Guide](configuration.md)
- [Troubleshooting](troubleshooting.md)
